import siteData from "virtual-site-data";
import {
  addLeadingSlash,
  removeTrailingSlash,
  normalizeSlash,
  isProduction,
  normalizeHref,
  withBase as rawWithBase,
  removeBase as rawRemoveBase,
  isExternalUrl,
  isDataUrl,
  removeHash
} from "@rspress/shared";
function normalizeRoutePath(routePath) {
  return decodeURIComponent(routePath).replace(/\.html$/, "").replace(/\/index$/, "/");
}
function withBase(url = "/") {
  return rawWithBase(url, siteData.base);
}
function removeBase(url) {
  return rawRemoveBase(url, siteData.base);
}
function isEqualPath(a, b) {
  return withBase(normalizeHrefInRuntime(removeHash(a))) === withBase(normalizeHrefInRuntime(removeHash(b)));
}
function normalizeHrefInRuntime(a) {
  const cleanUrls = Boolean(siteData?.route?.cleanUrls);
  return normalizeHref(a, cleanUrls);
}
function normalizeImagePath(imagePath) {
  const isProd = isProduction();
  if (!isProd) {
    return imagePath;
  }
  if (isExternalUrl(imagePath) || isDataUrl(imagePath)) {
    return imagePath;
  }
  return withBase(imagePath);
}
export {
  addLeadingSlash,
  isEqualPath,
  isProduction,
  normalizeHrefInRuntime,
  normalizeImagePath,
  normalizeRoutePath,
  normalizeSlash,
  removeBase,
  removeTrailingSlash,
  withBase
};
